from core import (
	ifthis, IfThis,
	thenthat, ThenThat 
)
from channels import channels
